﻿<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nb_NO">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../gui/aboutdialog.cpp" line="27"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
</context>
<context>
    <name>CallListener</name>
    <message>
        <source>Searching...</source>
        <translation>Søker...</translation>
    </message>
    <message>
        <source>Request timed out</source>
        <translation>Tilkobling mislyktes</translation>
    </message>
    <message>
        <source>Searching failed:</source>
        <translation>Søk feilet:</translation>
    </message>
    <message>
        <source>Phone number was not found</source>
        <translation>Nummeret ble ikke funnet</translation>
    </message>
    <message>
        <source>Automatic connecting is not allowed by settings.</source>
        <translation>Automatisk oppkobling ikke tillatt, sjekk innstillingene.</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Kobler til...</translation>
    </message>
    <message>
        <source>No available 3G or WLAN networks found.</source>
        <translation>Ingen tilgjengelige nettverk.</translation>
    </message>
    <message>
        <source>Selected access point doesn&apos;t exist.</source>
        <translation>Valgte tilgangspunkt finnes ikke.</translation>
    </message>
    <message>
        <source>Unable to connect to network.</source>
        <translation>Kan ikke koble til nettverket.</translation>
    </message>
</context>
<context>
    <name>ConnectionSelector</name>
    <message>
        <location filename="../../gui/connectionselector.cpp" line="69"/>
        <source>Use global setting</source>
        <translation>Bruk globale innstillinger</translation>
    </message>
    <message>
        <location filename="../../gui/connectionselector.cpp" line="70"/>
        <source>WLAN connection</source>
        <translation>WLAN tilkobling</translation>
    </message>
    <message>
        <location filename="../../gui/connectionselector.cpp" line="71"/>
        <source>GPRS connection</source>
        <translation>GPRS tilkobling</translation>
    </message>
    <message>
        <location filename="../../gui/connectionselector.cpp" line="72"/>
        <source>Any connection</source>
        <translation>Alle tilkoblinger</translation>
    </message>
</context>
<context>
    <name>DetailWindow</name>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="42"/>
        <location filename="../../gui/detailwindow.cpp" line="119"/>
        <source>Add to contacts</source>
        <translation>Legg til i kontakter</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="43"/>
        <source>Copy number to clipboard</source>
        <translation>Kopier nummer til utklippstavle</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="44"/>
        <source>Call</source>
        <translation>Ring</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="45"/>
        <source>Send SMS</source>
        <translation>Send SMS</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="53"/>
        <location filename="../../gui/detailwindow.cpp" line="122"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="54"/>
        <source>Street</source>
        <translation>Gate</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="55"/>
        <source>City</source>
        <translation>By</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="57"/>
        <source>Phone number</source>
        <translation>Telefonnummer</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="109"/>
        <source>Unable make call</source>
        <translation>Kan ikke foreta anrop</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="123"/>
        <source>Add</source>
        <translation>Legg til</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="156"/>
        <source>Contact was successfully added to contacts.</source>
        <translation>Kontakten ble lagt til i kontaktlisten.</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="194"/>
        <source>Unable to open SMS application</source>
        <translation>Kan ikke åpne SMS applikasjon</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="109"/>
        <location filename="../../gui/detailwindow.cpp" line="160"/>
        <location filename="../../gui/detailwindow.cpp" line="194"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="160"/>
        <source>Unable to add contact.</source>
        <translation>Kan ikke legge til kontakt.</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="170"/>
        <source>Number was successfully copied to clipboard.</source>
        <translation>Nummeret ble kopiert til utklippstavlen.</translation>
    </message>
</context>
<context>
    <name>EmptyGuiConfig</name>
    <message>
        <location filename="../../gui/emptyguiconfig.cpp" line="27"/>
        <source>Selected phonebook has no settings to configure.</source>
        <translation>Den valgte telefonkatalogen har ingen innstillinger.</translation>
    </message>
</context>
<context>
    <name>EniroGuiConfig</name>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="36"/>
        <source>Eniro username</source>
        <translation>Eniro username</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="39"/>
        <source>Eniro password</source>
        <translation>Eniro password</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="45"/>
        <source>Eniro site</source>
        <translation>Eniro site</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="57"/>
        <source>Finnish</source>
        <translation>Finnish</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="60"/>
        <source>Swedish</source>
        <translation>Swedish</translation>
    </message>
    <message>
        <location filename="../../gui/eniroguiconfig.cpp" line="63"/>
        <source>Danish</source>
        <translation>Danish</translation>
    </message>
</context>
<context>
    <name>LogWindow</name>
    <message>
        <location filename="../../gui/logwindow.cpp" line="30"/>
        <source>Incoming call log</source>
        <translation>Anropslogg</translation>
    </message>
    <message>
        <location filename="../../gui/logwindow.cpp" line="31"/>
        <source>Clear log</source>
        <translation>Tøm Logg</translation>
    </message>
    <message>
        <location filename="../../gui/logwindow.cpp" line="64"/>
        <source>There are currently no logged calls</source>
        <translation>Det er ingen mottatte anrop</translation>
    </message>
    <message>
        <location filename="../../gui/logwindow.cpp" line="134"/>
        <source>%1 (no search results)</source>
        <translation>%1 (ble ikke funnet)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="48"/>
        <source>Jenirok</source>
        <translation>Jenirok</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="54"/>
        <location filename="../../gui/mainwindow.cpp" line="151"/>
        <source>Stop daemon</source>
        <translation>Stopp autosøk</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="60"/>
        <location filename="../../gui/mainwindow.cpp" line="117"/>
        <source>Start daemon</source>
        <translation>Start autosøk</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="65"/>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="76"/>
        <source>Log</source>
        <translation>Logg</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="82"/>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="83"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="115"/>
        <source>Daemon was successfully stopped.</source>
        <translation>Autosøk ble stoppet.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="116"/>
        <source>Unable to stop daemon.</source>
        <translation>Kan ikke stoppe autosøk.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="127"/>
        <source>Unable to start daemon</source>
        <translation>Kan ikke starte autosøk.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="129"/>
        <source>Daemon cannot be started because it&apos;s not allowed to connect to the Internet. You have to either allow automatic Internet connection in Jenirok settings or in global Maemo settings.</source>
        <translation>Autosøk får ikke tilgang til internett. Du må enten tillate automatisk oppkobling til internett i Jenirok eller i globale Maemo innstillinger.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="133"/>
        <source>Open settings</source>
        <translation>Åpne innstillinger</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="135"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="149"/>
        <source>Daemon was successfully started.</source>
        <translation>Autosøk ble startet.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="150"/>
        <source>Unable to start daemon.</source>
        <translation>Kan ikke starte autosøk.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="157"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="181"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="181"/>
        <source>You need to set login details or other options in settings before using this feature.</source>
        <translation>Du må fylle inn påloggingsinformasjon for å bruke denne tjenesten.</translation>
    </message>
</context>
<context>
    <name>ResultWindow</name>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="36"/>
        <source>Search results</source>
        <translation>Søke resultater</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="163"/>
        <source>Connection to server failed</source>
        <translation>Tilkobling til server feilet</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="166"/>
        <source>Invalid login details</source>
        <translation>Feil påloggingsinformasjon</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="169"/>
        <source>Request timed out</source>
        <translation>Tilkobling feilet</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="172"/>
        <source>Searching failed:</source>
        <translation>Søk feilet:</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="176"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="181"/>
        <source>No results found</source>
        <translation>Ingen resultater funnet</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="30"/>
        <location filename="../../gui/searchdialog.cpp" line="55"/>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="33"/>
        <source>Name/number</source>
        <translation>Navn/Nummer</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="39"/>
        <source>Location</source>
        <translation>Sted</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="44"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="45"/>
        <source>Persons</source>
        <translation>Personer</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="46"/>
        <source>Companies</source>
        <translation>Firmaer</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.cpp" line="168"/>
        <source>fi</source>
        <translation>fi</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="44"/>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="58"/>
        <source>Cache size (numbers)</source>
        <translation>Cache størrelse</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="61"/>
        <source>Clear</source>
        <translation>Tøm</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="64"/>
        <source>Language</source>
        <translation>Språk</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="65"/>
        <source>Automatic</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="82"/>
        <source>Phonebook</source>
        <translation>Telefonkatalog</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="102"/>
        <source>Autostart</source>
        <translation>Automatisk start</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="104"/>
        <source>Enabled</source>
        <translation>Aktivert</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="105"/>
        <source>Disabled</source>
        <translation>Deaktivert</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="108"/>
        <source>Connect automatically on</source>
        <translation>Koble til automatisk</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="112"/>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="137"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="138"/>
        <source>Daemon</source>
        <translation>Autosøk</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="139"/>
        <location filename="../../gui/settingsdialog.cpp" line="208"/>
        <source>Phonebook settings</source>
        <translation>Telefonkatalog innst.</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="170"/>
        <source>Restarting daemon...</source>
        <translation>Restarter Autosøk...</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="176"/>
        <source>You need to restart Jenirok for language change to take effect.</source>
        <translation>Du må restarte Jenirok for å endre språk.</translation>
    </message>
    <message numerus="yes">
        <location filename="../../gui/settingsdialog.cpp" line="188"/>
        <source>%n number(s) were deleted from cache</source>
        <translation>
            <numerusform>Telefonnummeret ble slettet fra cache</numerusform>
            <numerusform>Telefonnummerene ble slettet fra cache</numerusform>
        </translation>
    </message>
</context>
</TS>
